# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RoleAssignment(Model):
    """Represents a role assignment Metadata.

    :param principal_id: Gets the Id of the principal.
    :type principal_id: str
    :param principal_type: Possible values include: 'user', 'group', 'app'
    :type principal_type: str or ~dynamics.customerinsights.api.models.enum
    :param roles: Gets the roles the principal belongs to.
    :type roles: list[str]
    :param instance_id: Customer Insights instance id associated with this
     object.
    :type instance_id: str
    """

    _attribute_map = {
        'principal_id': {'key': 'principalId', 'type': 'str'},
        'principal_type': {'key': 'principalType', 'type': 'str'},
        'roles': {'key': 'roles', 'type': '[str]'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(RoleAssignment, self).__init__(**kwargs)
        self.principal_id = kwargs.get('principal_id', None)
        self.principal_type = kwargs.get('principal_type', None)
        self.roles = kwargs.get('roles', None)
        self.instance_id = kwargs.get('instance_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EntityEnrichmentInformation(Model):
    """Represents the enrichment entity info used in API requests (entity level).

    :param has_enriched_entity: Gets a value indicating whether there is an
     enriched entity for the ds entity.
    :type has_enriched_entity: bool
    :param enriched_entity_name: Name of the enriched entity.
    :type enriched_entity_name: str
    :param configured_enrichments: Gets the list configured enrichments on the
     ds entity.
    :type configured_enrichments: list[str]
    """

    _attribute_map = {
        'has_enriched_entity': {'key': 'hasEnrichedEntity', 'type': 'bool'},
        'enriched_entity_name': {'key': 'enrichedEntityName', 'type': 'str'},
        'configured_enrichments': {'key': 'configuredEnrichments', 'type': '[str]'},
    }

    def __init__(self, *, has_enriched_entity: bool=None, enriched_entity_name: str=None, configured_enrichments=None, **kwargs) -> None:
        super(EntityEnrichmentInformation, self).__init__(**kwargs)
        self.has_enriched_entity = has_enriched_entity
        self.enriched_entity_name = enriched_entity_name
        self.configured_enrichments = configured_enrichments



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ScalarOutput(Model):
    """ScalarOutput.

    :param values: Output folder path for the evaluation.
    :type values: dict[str, str]
    :param measure_name:
    :type measure_name: str
    :param evaluation_time: Gets the evaluation start time.
    :type evaluation_time: datetime
    """

    _attribute_map = {
        'values': {'key': 'values', 'type': '{str}'},
        'measure_name': {'key': 'measureName', 'type': 'str'},
        'evaluation_time': {'key': 'evaluationTime', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(ScalarOutput, self).__init__(**kwargs)
        self.values = kwargs.get('values', None)
        self.measure_name = kwargs.get('measure_name', None)
        self.evaluation_time = kwargs.get('evaluation_time', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Quantiles(Model):
    """Numerical quantiles.

    :param p0_d1: Represents 1% quantile.
    :type p0_d1: float
    :param p1: Represents 1% quantile.
    :type p1: float
    :param p5: Represents 5% quantile.
    :type p5: float
    :param p25: Represents 25% quantile.
    :type p25: float
    :param p50: Represents 50% quantile.
    :type p50: float
    :param p75: Represents 75% quantile.
    :type p75: float
    :param p95: Represents 95% quantile.
    :type p95: float
    :param p99: Represents 99% quantile.
    :type p99: float
    :param p99_d9: Represents 9% quantile.
    :type p99_d9: float
    """

    _attribute_map = {
        'p0_d1': {'key': 'p0D1', 'type': 'float'},
        'p1': {'key': 'p1', 'type': 'float'},
        'p5': {'key': 'p5', 'type': 'float'},
        'p25': {'key': 'p25', 'type': 'float'},
        'p50': {'key': 'p50', 'type': 'float'},
        'p75': {'key': 'p75', 'type': 'float'},
        'p95': {'key': 'p95', 'type': 'float'},
        'p99': {'key': 'p99', 'type': 'float'},
        'p99_d9': {'key': 'p99D9', 'type': 'float'},
    }

    def __init__(self, *, p0_d1: float=None, p1: float=None, p5: float=None, p25: float=None, p50: float=None, p75: float=None, p95: float=None, p99: float=None, p99_d9: float=None, **kwargs) -> None:
        super(Quantiles, self).__init__(**kwargs)
        self.p0_d1 = p0_d1
        self.p1 = p1
        self.p5 = p5
        self.p25 = p25
        self.p50 = p50
        self.p75 = p75
        self.p95 = p95
        self.p99 = p99
        self.p99_d9 = p99_d9



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HierarchyDependency(Model):
    """Represents metadata for a Hierarchy Dependency.

    :param source_entity: Gets the source entities fully qualified name.
    :type source_entity: str
    :param account_id_attribute: Gets entity account Id.
    :type account_id_attribute: str
    :param parent_account_id_attribute: Gets parent account id.
    :type parent_account_id_attribute: str
    """

    _attribute_map = {
        'source_entity': {'key': 'sourceEntity', 'type': 'str'},
        'account_id_attribute': {'key': 'accountIdAttribute', 'type': 'str'},
        'parent_account_id_attribute': {'key': 'parentAccountIdAttribute', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(HierarchyDependency, self).__init__(**kwargs)
        self.source_entity = kwargs.get('source_entity', None)
        self.account_id_attribute = kwargs.get('account_id_attribute', None)
        self.parent_account_id_attribute = kwargs.get('parent_account_id_attribute', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Moments(Model):
    """Statistical moments.

    :param mean: Represents the mean.
    :type mean: float
    :param standard_deviation: Represents standard deviation.
    :type standard_deviation: float
    :param variance: Represents variance.
    :type variance: float
    :param skewness: Represents skewness in data.
    :type skewness: float
    :param kurtosis: Represents kurtosis.
    :type kurtosis: float
    """

    _attribute_map = {
        'mean': {'key': 'mean', 'type': 'float'},
        'standard_deviation': {'key': 'standardDeviation', 'type': 'float'},
        'variance': {'key': 'variance', 'type': 'float'},
        'skewness': {'key': 'skewness', 'type': 'float'},
        'kurtosis': {'key': 'kurtosis', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(Moments, self).__init__(**kwargs)
        self.mean = kwargs.get('mean', None)
        self.standard_deviation = kwargs.get('standard_deviation', None)
        self.variance = kwargs.get('variance', None)
        self.skewness = kwargs.get('skewness', None)
        self.kurtosis = kwargs.get('kurtosis', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CdsMdlInfo(Model):
    """The information on CDS MDL datalake folders.

    :param private_work_space:
    :type private_work_space:
     ~dynamics.customerinsights.api.models.DatalakeFolderDetail
    :param public_work_space:
    :type public_work_space:
     ~dynamics.customerinsights.api.models.DatalakeFolderDetail
    """

    _attribute_map = {
        'private_work_space': {'key': 'privateWorkSpace', 'type': 'DatalakeFolderDetail'},
        'public_work_space': {'key': 'publicWorkSpace', 'type': 'DatalakeFolderDetail'},
    }

    def __init__(self, **kwargs):
        super(CdsMdlInfo, self).__init__(**kwargs)
        self.private_work_space = kwargs.get('private_work_space', None)
        self.public_work_space = kwargs.get('public_work_space', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ODataTypeAnnotation(Model):
    """ODataTypeAnnotation.

    :param type_name:
    :type type_name: str
    """

    _attribute_map = {
        'type_name': {'key': 'typeName', 'type': 'str'},
    }

    def __init__(self, *, type_name: str=None, **kwargs) -> None:
        super(ODataTypeAnnotation, self).__init__(**kwargs)
        self.type_name = type_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Relationship(Model):
    """Relationship.

    :param name:
    :type name: str
    :param description:
    :type description: str
    :param annotations:
    :type annotations: list[~dynamics.customerinsights.api.models.Annotation]
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'annotations': {'key': 'annotations', 'type': '[Annotation]'},
    }

    def __init__(self, *, name: str=None, description: str=None, annotations=None, **kwargs) -> None:
        super(Relationship, self).__init__(**kwargs)
        self.name = name
        self.description = description
        self.annotations = annotations



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CustomTaskInformation(Model):
    """Represents custom information about a task.

    :param kind: Possible values include: 'test', 'segmentation', 'measures',
     'export', 'incrementalIngestion', 'incrementalMatch',
     'incrementalMatchWithPreview', 'merge', 'mark', 'affinities'
    :type kind: str or ~dynamics.customerinsights.api.models.enum
    """

    _attribute_map = {
        'kind': {'key': 'kind', 'type': 'str'},
    }

    def __init__(self, *, kind=None, **kwargs) -> None:
        super(CustomTaskInformation, self).__init__(**kwargs)
        self.kind = kind



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DatalakeFolderDetail(Model):
    """The information for datalake folder in CDS.

    :param name: Gets the datalake folder Friendly Name
    :type name: str
    :param unique_name: Gets the Cds datalake folder unique Name
    :type unique_name: str
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'unique_name': {'key': 'uniqueName', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(DatalakeFolderDetail, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.unique_name = kwargs.get('unique_name', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AttributeSemanticInformation(Model):
    """Represents the semantic info used in API requests (attribute level).

    :param attribute_name: Name of the attribute.
    :type attribute_name: str
    :param label: Semantic label. Possible values include: 'CalendarDate',
     'CalendarDayOfMonth', 'CalendarDayOfWeek', 'CalendarDayOfYear',
     'CalendarHalfYear', 'CalendarMonthOfYear', 'CalendarMonth',
     'CalendarWeek', 'CalendarYear', 'CalendarFiscalDate',
     'CalendarFiscalDayOfMonth', 'CalendarFiscalDayOfWeek',
     'CalendarFiscalDayOfYear', 'CalendarFiscalHalfYear',
     'CalendarFiscalMonthOfYear', 'CalendarFiscalMonth',
     'CalendarFiscalQuarter', 'CalendarFiscalWeekOfMonth',
     'CalendarFiscalWeekOfYear', 'CalendarFiscalWeek', 'CalendarFiscalYear',
     'Account', 'Channel', 'Contact', 'Customer', 'Language', 'Organization',
     'OrganizationUnit', 'Person', 'Product', 'ProductGroup',
     'LocationAddress', 'LocationAddressStreet', 'LocationCity',
     'LocationContinent', 'LocationCountry', 'LocationCounty',
     'LocationLatitude', 'LocationLongitude', 'LocationPoint',
     'LocationPostalCode', 'LocationProvince', 'LocationRegion',
     'LocationState', 'LocationTimezone', 'MeasurementDateCreation',
     'MeasurementDateModify', 'MeasurementStatus', 'MeasurementVersion',
     'BarCode', 'Brand', 'IdentityGovernmentID', 'PersonFirstName',
     'PersonFullName', 'PersonLastName', 'PersonMiddleName',
     'IdentityServiceEmail', 'IdentityServiceFacebook', 'IdentityServicePhone',
     'IdentityServiceTwitter', 'Image', 'Place', 'ReferenceDescription',
     'ReferenceImageURL', 'ReferencePhonetic', 'ReferenceURL'
    :type label: str or ~dynamics.customerinsights.api.models.enum
    """

    _attribute_map = {
        'attribute_name': {'key': 'attributeName', 'type': 'str'},
        'label': {'key': 'label', 'type': 'str'},
    }

    def __init__(self, *, attribute_name: str=None, label=None, **kwargs) -> None:
        super(AttributeSemanticInformation, self).__init__(**kwargs)
        self.attribute_name = attribute_name
        self.label = label



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstanceInfo(Model):
    """The instance info.

    :param instance_id: Gets the unique ID for this instance.
    :type instance_id: str
    :param name: Gets the instance name. (not persisted in store)
    :type name: str
    :param instance_type: Possible values include: 'trial', 'sandbox',
     'production', 'pitchDemo', 'pov'
    :type instance_type: str or ~dynamics.customerinsights.api.models.enum
    :param expiry_time_utc: Gets the time the instance is set to expire. (not
     persisted in store)
    :type expiry_time_utc: datetime
    :param max_trial_extensions_allowed: Gets the total number of extensions
     allowed if this is trial instance (not persisted in store)
    :type max_trial_extensions_allowed: int
    :param trial_extension_history: Stores the details of trial extensions
     done if this is a trial instance (not persisted in store)
    :type trial_extension_history: str
    :param scale_unit_id: Gets the unique identifier for the scale unit (not
     persisted in store)
    :type scale_unit_id: str
    :param azure_region: Gets the Azure Region where the scale unit resides
     (not persisted in store)
    :type azure_region: str
    :param platform_type: Gets the Insights App Type for g. Verity, Engagement
     Insight etc. (not persisted in store)
    :type platform_type: str
    """

    _attribute_map = {
        'instance_id': {'key': 'instanceId', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'instance_type': {'key': 'instanceType', 'type': 'str'},
        'expiry_time_utc': {'key': 'expiryTimeUtc', 'type': 'iso-8601'},
        'max_trial_extensions_allowed': {'key': 'maxTrialExtensionsAllowed', 'type': 'int'},
        'trial_extension_history': {'key': 'trialExtensionHistory', 'type': 'str'},
        'scale_unit_id': {'key': 'scaleUnitId', 'type': 'str'},
        'azure_region': {'key': 'azureRegion', 'type': 'str'},
        'platform_type': {'key': 'platformType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(InstanceInfo, self).__init__(**kwargs)
        self.instance_id = kwargs.get('instance_id', None)
        self.name = kwargs.get('name', None)
        self.instance_type = kwargs.get('instance_type', None)
        self.expiry_time_utc = kwargs.get('expiry_time_utc', None)
        self.max_trial_extensions_allowed = kwargs.get('max_trial_extensions_allowed', None)
        self.trial_extension_history = kwargs.get('trial_extension_history', None)
        self.scale_unit_id = kwargs.get('scale_unit_id', None)
        self.azure_region = kwargs.get('azure_region', None)
        self.platform_type = kwargs.get('platform_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SegmentationRowset(Model):
    """Represent a Row set.

    :param rowset_operation: Possible values include: 'union', 'intersect',
     'except', 'none', 'include', 'exclude'
    :type rowset_operation: str or ~dynamics.customerinsights.api.models.enum
    :param criteria:
    :type criteria:
     ~dynamics.customerinsights.api.models.SegmentMembershipCriteria
    :param paths: Gets the relationship path to use for segment criteria.
    :type paths: list[list[str]]
    :param rowset_id: Gets the rowset Id in the rowsets.
    :type rowset_id: str
    """

    _attribute_map = {
        'rowset_operation': {'key': 'rowsetOperation', 'type': 'str'},
        'criteria': {'key': 'criteria', 'type': 'SegmentMembershipCriteria'},
        'paths': {'key': 'paths', 'type': '[[str]]'},
        'rowset_id': {'key': 'rowsetId', 'type': 'str'},
    }

    def __init__(self, *, rowset_operation=None, criteria=None, paths=None, rowset_id: str=None, **kwargs) -> None:
        super(SegmentationRowset, self).__init__(**kwargs)
        self.rowset_operation = rowset_operation
        self.criteria = criteria
        self.paths = paths
        self.rowset_id = rowset_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EntityDataProfile(Model):
    """Represents Entity Data Profile information.

    :param qualified_entity_name: Qualified Entity Name.
    :type qualified_entity_name: str
    :param row_count: Row count.
    :type row_count: long
    :param quarantine_row_count: Quarentine row count
    :type quarantine_row_count: long
    :param profiling_date: Date for Profiling.
    :type profiling_date: datetime
    :param profiled_attributes: Profiling attributes.
    :type profiled_attributes: str
    :param corrupt_attributes: Respresents currupt attributes.
    :type corrupt_attributes: str
    :param attribute_data_profiles: Contains all the attributes data profiles.
    :type attribute_data_profiles:
     list[~dynamics.customerinsights.api.models.AttributeDataProfile]
    """

    _attribute_map = {
        'qualified_entity_name': {'key': 'qualifiedEntityName', 'type': 'str'},
        'row_count': {'key': 'rowCount', 'type': 'long'},
        'quarantine_row_count': {'key': 'quarantineRowCount', 'type': 'long'},
        'profiling_date': {'key': 'profilingDate', 'type': 'iso-8601'},
        'profiled_attributes': {'key': 'profiledAttributes', 'type': 'str'},
        'corrupt_attributes': {'key': 'corruptAttributes', 'type': 'str'},
        'attribute_data_profiles': {'key': 'attributeDataProfiles', 'type': '[AttributeDataProfile]'},
    }

    def __init__(self, *, qualified_entity_name: str=None, row_count: int=None, quarantine_row_count: int=None, profiling_date=None, profiled_attributes: str=None, corrupt_attributes: str=None, attribute_data_profiles=None, **kwargs) -> None:
        super(EntityDataProfile, self).__init__(**kwargs)
        self.qualified_entity_name = qualified_entity_name
        self.row_count = row_count
        self.quarantine_row_count = quarantine_row_count
        self.profiling_date = profiling_date
        self.profiled_attributes = profiled_attributes
        self.corrupt_attributes = corrupt_attributes
        self.attribute_data_profiles = attribute_data_profiles



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DismissedNotification(Model):
    """Represents a dismissed notification.

    :param notification_id: Gets the unique id of the notification
    :type notification_id: str
    :param notification_expiry_time_utc: Gets the expiration UTC date time of
     this notification.
    :type notification_expiry_time_utc: datetime
    """

    _attribute_map = {
        'notification_id': {'key': 'notificationId', 'type': 'str'},
        'notification_expiry_time_utc': {'key': 'notificationExpiryTimeUtc', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(DismissedNotification, self).__init__(**kwargs)
        self.notification_id = kwargs.get('notification_id', None)
        self.notification_expiry_time_utc = kwargs.get('notification_expiry_time_utc', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ODataValue(Model):
    """ODataValue.

    :param type_annotation:
    :type type_annotation:
     ~dynamics.customerinsights.api.models.ODataTypeAnnotation
    """

    _attribute_map = {
        'type_annotation': {'key': 'typeAnnotation', 'type': 'ODataTypeAnnotation'},
    }

    def __init__(self, *, type_annotation=None, **kwargs) -> None:
        super(ODataValue, self).__init__(**kwargs)
        self.type_annotation = type_annotation



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeasureMetadata(Model):
    """Represents metadata for a measure (or KPI).

    :param display_name:
    :type display_name: str
    :param name: Unique name of the measure
    :type name: str
    :param description: Description of the measure.
    :type description: str
    :param definition:
    :type definition: ~dynamics.customerinsights.api.models.MeasureDefinition
    :param latest_evaluation:
    :type latest_evaluation: ~dynamics.customerinsights.api.models.Evaluation
    :param output:
    :type output: ~dynamics.customerinsights.api.models.ScalarOutput
    :param evaluation_stats:
    :type evaluation_stats:
     ~dynamics.customerinsights.api.models.EvaluationStats
    :param error_description:
    :type error_description: ~dynamics.customerinsights.api.models.StringInfo
    :param sql_validation_stats:
    :type sql_validation_stats:
     ~dynamics.customerinsights.api.models.SqlValidationStats
    :param evaluation_history: Evaluation history for the measure. (not
     persisted in store)
    :type evaluation_history:
     list[~dynamics.customerinsights.api.models.Evaluation]
    :param output_history: Output history for the measure. (not persisted in
     store)
    :type output_history:
     list[~dynamics.customerinsights.api.models.ScalarOutput]
    :param is_template: Check if measure metadata is a template
    :type is_template: bool
    :param template_id: Gets the template ID for templates
    :type template_id: str
    :param is_created_from_template: Check if measure metadata is created from
     a template. Default value: False .
    :type is_created_from_template: bool
    :param version: Version number of this object.
    :type version: long
    :param updated_by: UPN of the user who last updated this record.
    :type updated_by: str
    :param updated_utc: Time this object was last updated.
    :type updated_utc: datetime
    :param created_by: Email address of the user who created this record.
    :type created_by: str
    :param created_utc: Time this object was initially created.
    :type created_utc: datetime
    :param instance_id: Customer Insights instance id associated with this
     object.
    :type instance_id: str
    """

    _attribute_map = {
        'display_name': {'key': 'displayName', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'definition': {'key': 'definition', 'type': 'MeasureDefinition'},
        'latest_evaluation': {'key': 'latestEvaluation', 'type': 'Evaluation'},
        'output': {'key': 'output', 'type': 'ScalarOutput'},
        'evaluation_stats': {'key': 'evaluationStats', 'type': 'EvaluationStats'},
        'error_description': {'key': 'errorDescription', 'type': 'StringInfo'},
        'sql_validation_stats': {'key': 'sqlValidationStats', 'type': 'SqlValidationStats'},
        'evaluation_history': {'key': 'evaluationHistory', 'type': '[Evaluation]'},
        'output_history': {'key': 'outputHistory', 'type': '[ScalarOutput]'},
        'is_template': {'key': 'isTemplate', 'type': 'bool'},
        'template_id': {'key': 'templateId', 'type': 'str'},
        'is_created_from_template': {'key': 'isCreatedFromTemplate', 'type': 'bool'},
        'version': {'key': 'version', 'type': 'long'},
        'updated_by': {'key': 'updatedBy', 'type': 'str'},
        'updated_utc': {'key': 'updatedUtc', 'type': 'iso-8601'},
        'created_by': {'key': 'createdBy', 'type': 'str'},
        'created_utc': {'key': 'createdUtc', 'type': 'iso-8601'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, *, display_name: str=None, name: str=None, description: str=None, definition=None, latest_evaluation=None, output=None, evaluation_stats=None, error_description=None, sql_validation_stats=None, evaluation_history=None, output_history=None, is_template: bool=None, template_id: str=None, is_created_from_template: bool=False, version: int=None, updated_by: str=None, updated_utc=None, created_by: str=None, created_utc=None, instance_id: str=None, **kwargs) -> None:
        super(MeasureMetadata, self).__init__(**kwargs)
        self.display_name = display_name
        self.name = name
        self.description = description
        self.definition = definition
        self.latest_evaluation = latest_evaluation
        self.output = output
        self.evaluation_stats = evaluation_stats
        self.error_description = error_description
        self.sql_validation_stats = sql_validation_stats
        self.evaluation_history = evaluation_history
        self.output_history = output_history
        self.is_template = is_template
        self.template_id = template_id
        self.is_created_from_template = is_created_from_template
        self.version = version
        self.updated_by = updated_by
        self.updated_utc = updated_utc
        self.created_by = created_by
        self.created_utc = created_utc
        self.instance_id = instance_id



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="customerinsights",
    version="1.0.8",
    author="Microsoft Corp.",
    author_email="cihelp@microsoft.com",
    description="Client library for interacting with Customer Insights APIs",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://docs.microsoft.com/en-us/dynamics365/ai/customer-insights/pm-apis",
    packages=setuptools.find_packages(),
    classifiers=[
    ],
    python_requires='>=2.7',
)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IC360EntityModel(Model):
    """Represents Entity Model.

    :param instance_id: Gets the instance ID associated with the model.
    :type instance_id: str
    :param dataflow_id: Gets the dataflow ID associated with the model.
    :type dataflow_id: str
    :param datasource_id: Gets the datasource ID associated with the model.
    :type datasource_id: str
    :param dataflow_type: Possible values include: 'dynamics365',
     'salesforce', 'conflationSortAndRefine', 'conflationDeduplication',
     'conflationMatchPairs', 'conflationResolveConflicts', 'enriched', 'kpi',
     'powerQuery', 'dataPreparation', 'intelligence', 'unifiedActivity',
     'segmentation', 'ingestion', 'attachCdm', 'genericPrediction',
     'attachCds', 'unknown', 'powerPlatform', 'datahub', 'insights',
     'derivedEntity', 'powerPlatformSource', 'powerPlatformBYDL',
     'powerPlatformBYDLSource', 'semanticActivity', 'segmentMembership',
     'firstParty', 'hierarchy', 'contact', 'semanticEntity', 'attachSynapse',
     'transform'
    :type dataflow_type: str or ~dynamics.customerinsights.api.models.enum
    :param entities: Gets entities in the model.
    :type entities:
     list[~dynamics.customerinsights.api.models.IEntityMetadata]
    """

    _attribute_map = {
        'instance_id': {'key': 'instanceId', 'type': 'str'},
        'dataflow_id': {'key': 'dataflowId', 'type': 'str'},
        'datasource_id': {'key': 'datasourceId', 'type': 'str'},
        'dataflow_type': {'key': 'dataflowType', 'type': 'str'},
        'entities': {'key': 'entities', 'type': '[IEntityMetadata]'},
    }

    def __init__(self, *, instance_id: str=None, dataflow_id: str=None, datasource_id: str=None, dataflow_type=None, entities=None, **kwargs) -> None:
        super(IC360EntityModel, self).__init__(**kwargs)
        self.instance_id = instance_id
        self.dataflow_id = dataflow_id
        self.datasource_id = datasource_id
        self.dataflow_type = dataflow_type
        self.entities = entities



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ProfileStoreModuleRunInfo(Model):
    """ProfileStoreModuleRunInfo.

    :param run_info: LastSuccessfulRunId Info for every fullyQualifiedEntity.
    :type run_info: dict[str, str]
    """

    _attribute_map = {
        'run_info': {'key': 'runInfo', 'type': '{str}'},
    }

    def __init__(self, **kwargs):
        super(ProfileStoreModuleRunInfo, self).__init__(**kwargs)
        self.run_info = kwargs.get('run_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstanceMetadata(Model):
    """The instance metadata.

    :param is_b2_b:
    :type is_b2_b: bool
    :param is_b2_c:
    :type is_b2_c: bool
    :param is_byo_pbi:
    :type is_byo_pbi: bool
    :param is_byo_synapse:
    :type is_byo_synapse: bool
    :param is_cds_mdl_or_cds_byodl:
    :type is_cds_mdl_or_cds_byodl: bool
    :param name: Gets the user defined instance name.
    :type name: str
    :param provisioning_state: Possible values include: 'new', 'creating',
     'active', 'createFailed', 'updateFailed', 'deleting',
     'refreshCredentials', 'resetInstanceInProgress', 'updating',
     'quickUpdate', 'deactivated'
    :type provisioning_state: str or
     ~dynamics.customerinsights.api.models.enum
    :param instance_type: Possible values include: 'trial', 'sandbox',
     'production', 'pitchDemo', 'pov'
    :type instance_type: str or ~dynamics.customerinsights.api.models.enum
    :param refresh_schedule:
    :type refresh_schedule:
     ~dynamics.customerinsights.api.models.DataRefreshSchedule
    :param expiry_time_utc: Gets the time the instance is set to expire.
    :type expiry_time_utc: datetime
    :param region: Gets the Azure region where the instance lives.
    :type region: str
    :param cds_org_info:
    :type cds_org_info: ~dynamics.customerinsights.api.models.CdsOrgInfo
    :param cds_mdl_info:
    :type cds_mdl_info: ~dynamics.customerinsights.api.models.CdsMdlInfo
    :param max_trial_extensions_allowed: Gets the total number of extensions
     allowed if this is trial instance
    :type max_trial_extensions_allowed: int
    :param trial_extension_history: Stores the details of trial extensions
     done if this is a trial instance
    :type trial_extension_history: str
    :param is_refresh_credential_required: Gets a value indicating if
     credential  is required to refresh any of the datasources
    :type is_refresh_credential_required: bool
    :param trial_extension_details: Stores the details of trial extensions
     done if this is a trial instance
    :type trial_extension_details:
     list[~dynamics.customerinsights.api.models.TrialExtensionDetails]
    :param configured_workspaces: Gets the Workspace type, whether B2B or B2C
     (Main)
    :type configured_workspaces: list[str]
    :param platform_type: Field to store the Insights Partner who are
     onboarded to Insights Platform.
    :type platform_type: str
    :param azure_region: Gets the Azure Region where the scale unit resides
     (not persisted in store)
    :type azure_region: str
    :param version: Version number of this object.
    :type version: long
    :param updated_by: UPN of the user who last updated this record.
    :type updated_by: str
    :param updated_utc: Time this object was last updated.
    :type updated_utc: datetime
    :param created_by: Email address of the user who created this record.
    :type created_by: str
    :param created_utc: Time this object was initially created.
    :type created_utc: datetime
    :param instance_id: Customer Insights instance id associated with this
     object.
    :type instance_id: str
    """

    _attribute_map = {
        'is_b2_b': {'key': 'isB2B', 'type': 'bool'},
        'is_b2_c': {'key': 'isB2C', 'type': 'bool'},
        'is_byo_pbi': {'key': 'isByoPbi', 'type': 'bool'},
        'is_byo_synapse': {'key': 'isByoSynapse', 'type': 'bool'},
        'is_cds_mdl_or_cds_byodl': {'key': 'isCdsMdlOrCdsByodl', 'type': 'bool'},
        'name': {'key': 'name', 'type': 'str'},
        'provisioning_state': {'key': 'provisioningState', 'type': 'str'},
        'instance_type': {'key': 'instanceType', 'type': 'str'},
        'refresh_schedule': {'key': 'refreshSchedule', 'type': 'DataRefreshSchedule'},
        'expiry_time_utc': {'key': 'expiryTimeUtc', 'type': 'iso-8601'},
        'region': {'key': 'region', 'type': 'str'},
        'cds_org_info': {'key': 'cdsOrgInfo', 'type': 'CdsOrgInfo'},
        'cds_mdl_info': {'key': 'cdsMdlInfo', 'type': 'CdsMdlInfo'},
        'max_trial_extensions_allowed': {'key': 'maxTrialExtensionsAllowed', 'type': 'int'},
        'trial_extension_history': {'key': 'trialExtensionHistory', 'type': 'str'},
        'is_refresh_credential_required': {'key': 'isRefreshCredentialRequired', 'type': 'bool'},
        'trial_extension_details': {'key': 'trialExtensionDetails', 'type': '[TrialExtensionDetails]'},
        'configured_workspaces': {'key': 'configuredWorkspaces', 'type': '[str]'},
        'platform_type': {'key': 'platformType', 'type': 'str'},
        'azure_region': {'key': 'azureRegion', 'type': 'str'},
        'version': {'key': 'version', 'type': 'long'},
        'updated_by': {'key': 'updatedBy', 'type': 'str'},
        'updated_utc': {'key': 'updatedUtc', 'type': 'iso-8601'},
        'created_by': {'key': 'createdBy', 'type': 'str'},
        'created_utc': {'key': 'createdUtc', 'type': 'iso-8601'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(InstanceMetadata, self).__init__(**kwargs)
        self.is_b2_b = kwargs.get('is_b2_b', None)
        self.is_b2_c = kwargs.get('is_b2_c', None)
        self.is_byo_pbi = kwargs.get('is_byo_pbi', None)
        self.is_byo_synapse = kwargs.get('is_byo_synapse', None)
        self.is_cds_mdl_or_cds_byodl = kwargs.get('is_cds_mdl_or_cds_byodl', None)
        self.name = kwargs.get('name', None)
        self.provisioning_state = kwargs.get('provisioning_state', None)
        self.instance_type = kwargs.get('instance_type', None)
        self.refresh_schedule = kwargs.get('refresh_schedule', None)
        self.expiry_time_utc = kwargs.get('expiry_time_utc', None)
        self.region = kwargs.get('region', None)
        self.cds_org_info = kwargs.get('cds_org_info', None)
        self.cds_mdl_info = kwargs.get('cds_mdl_info', None)
        self.max_trial_extensions_allowed = kwargs.get('max_trial_extensions_allowed', None)
        self.trial_extension_history = kwargs.get('trial_extension_history', None)
        self.is_refresh_credential_required = kwargs.get('is_refresh_credential_required', None)
        self.trial_extension_details = kwargs.get('trial_extension_details', None)
        self.configured_workspaces = kwargs.get('configured_workspaces', None)
        self.platform_type = kwargs.get('platform_type', None)
        self.azure_region = kwargs.get('azure_region', None)
        self.version = kwargs.get('version', None)
        self.updated_by = kwargs.get('updated_by', None)
        self.updated_utc = kwargs.get('updated_utc', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_utc = kwargs.get('created_utc', None)
        self.instance_id = kwargs.get('instance_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HierarchyMetadata(Model):
    """Represents metadata for a Account Hierarchy.

    :param name: Gets the unique name of the hierarchy.
    :type name: str
    :param display_name: Gets the Display name of the hierarchy.
    :type display_name: str
    :param dependency:
    :type dependency:
     ~dynamics.customerinsights.api.models.HierarchyDependency
    :param version: Version number of this object.
    :type version: long
    :param updated_by: UPN of the user who last updated this record.
    :type updated_by: str
    :param updated_utc: Time this object was last updated.
    :type updated_utc: datetime
    :param created_by: Email address of the user who created this record.
    :type created_by: str
    :param created_utc: Time this object was initially created.
    :type created_utc: datetime
    :param instance_id: Customer Insights instance id associated with this
     object.
    :type instance_id: str
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'display_name': {'key': 'displayName', 'type': 'str'},
        'dependency': {'key': 'dependency', 'type': 'HierarchyDependency'},
        'version': {'key': 'version', 'type': 'long'},
        'updated_by': {'key': 'updatedBy', 'type': 'str'},
        'updated_utc': {'key': 'updatedUtc', 'type': 'iso-8601'},
        'created_by': {'key': 'createdBy', 'type': 'str'},
        'created_utc': {'key': 'createdUtc', 'type': 'iso-8601'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, *, name: str=None, display_name: str=None, dependency=None, version: int=None, updated_by: str=None, updated_utc=None, created_by: str=None, created_utc=None, instance_id: str=None, **kwargs) -> None:
        super(HierarchyMetadata, self).__init__(**kwargs)
        self.name = name
        self.display_name = display_name
        self.dependency = dependency
        self.version = version
        self.updated_by = updated_by
        self.updated_utc = updated_utc
        self.created_by = created_by
        self.created_utc = created_utc
        self.instance_id = instance_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeasureExpression(Model):
    """Base class to represent a measure expression.

    :param kind: Possible values include: 'constant', 'property',
     'memberAccess', 'functionCall', 'and', 'or', 'equals', 'notEquals',
     'greaterThan', 'greaterThanOrEqualTo', 'lessThan', 'lessThanOrEqualTo',
     'contains', 'startsWith', 'endsWith', 'isNull', 'isNotNull', 'negate',
     'add', 'subtract', 'multiply', 'divide', 'modulo', 'exponent', 'today',
     'now'
    :type kind: str or ~dynamics.customerinsights.api.models.enum
    """

    _attribute_map = {
        'kind': {'key': 'kind', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(MeasureExpression, self).__init__(**kwargs)
        self.kind = kwargs.get('kind', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ProfileStoreCollectionInfo(Model):
    """ProfileStoreCollectionInfo.

    :param current_state: Possible values include: 'empty', 'inBuild',
     'queryable'
    :type current_state: str or ~dynamics.customerinsights.api.models.enum
    :param row_count: Gets the row count of customer file yielded from merge
     output.
    :type row_count: long
    :param size: Gets the size of customer file yielded from merge .
    :type size: long
    :param profile_store_hydration_state_info: Gets the state of profile store
     hydration per job type.
    :type profile_store_hydration_state_info: dict[str, str]
    """

    _attribute_map = {
        'current_state': {'key': 'currentState', 'type': 'str'},
        'row_count': {'key': 'rowCount', 'type': 'long'},
        'size': {'key': 'size', 'type': 'long'},
        'profile_store_hydration_state_info': {'key': 'profileStoreHydrationStateInfo', 'type': '{str}'},
    }

    def __init__(self, **kwargs):
        super(ProfileStoreCollectionInfo, self).__init__(**kwargs)
        self.current_state = kwargs.get('current_state', None)
        self.row_count = kwargs.get('row_count', None)
        self.size = kwargs.get('size', None)
        self.profile_store_hydration_state_info = kwargs.get('profile_store_hydration_state_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PortalSettings(Model):
    """Represents a mapping  that can store all user ids associated with the
    email.

    :param coachmarks:
    :type coachmarks: ~dynamics.customerinsights.api.models.Coachmarks
    :param banners:
    :type banners: ~dynamics.customerinsights.api.models.Banners
    :param notifications:
    :type notifications: ~dynamics.customerinsights.api.models.Notifications
    :param is_existing_user: Gets a value indicating whether the user has seen
     the all apps (welcome) page.
    :type is_existing_user: bool
    :param show_default_home_page: Gets a value indicating whether the user
     has seen the all apps (welcome) page.
    :type show_default_home_page: bool
    :param pro_tagger: Gets a value indicating whether the user has seen the
     all apps (welcome) page.
    :type pro_tagger: bool
    """

    _attribute_map = {
        'coachmarks': {'key': 'coachmarks', 'type': 'Coachmarks'},
        'banners': {'key': 'banners', 'type': 'Banners'},
        'notifications': {'key': 'notifications', 'type': 'Notifications'},
        'is_existing_user': {'key': 'isExistingUser', 'type': 'bool'},
        'show_default_home_page': {'key': 'showDefaultHomePage', 'type': 'bool'},
        'pro_tagger': {'key': 'proTagger', 'type': 'bool'},
    }

    def __init__(self, *, coachmarks=None, banners=None, notifications=None, is_existing_user: bool=None, show_default_home_page: bool=None, pro_tagger: bool=None, **kwargs) -> None:
        super(PortalSettings, self).__init__(**kwargs)
        self.coachmarks = coachmarks
        self.banners = banners
        self.notifications = notifications
        self.is_existing_user = is_existing_user
        self.show_default_home_page = show_default_home_page
        self.pro_tagger = pro_tagger



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GraphNodeInfo(Model):
    """GraphNodeInfo.

    :param operation_type: Possible values include: 'none', 'ingestion',
     'derivedEntity', 'hierarchy', 'dataPreparation', 'map',
     'realtimeM3Search', 'match', 'merge', 'profileStore', 'search',
     'activity', 'contact', 'attributeMeasures', 'entityMeasures', 'measures',
     'segmentation', 'segmentMembership', 'enrichment', 'preEnrichment',
     'transform', 'intelligence', 'aiBuilder', 'insights', 'export',
     'modelManagement', 'relationship', 'roleAssignment', 'analysis',
     'semanticEntity', 'all'
    :type operation_type: str or ~dynamics.customerinsights.api.models.enum
    :param sub_type: Possible values include: 'noSubType',
     'templatedMeasures', 'createAnalysisModel', 'linkAnalysisModel',
     'singleActivityMapping', 'powerPlatform'
    :type sub_type: str or ~dynamics.customerinsights.api.models.enum
    :param identifier:
    :type identifier: str
    :param friendly_name:
    :type friendly_name: str
    :param job_ids:
    :type job_ids: list[str]
    :param task_status: Possible values include: 'queued', 'needsUpdate',
     'running', 'failed', 'timedOut', 'aborted', 'deleted', 'successful',
     'skipped'
    :type task_status: str or ~dynamics.customerinsights.api.models.enum
    :param last_success_job_ids:
    :type last_success_job_ids: list[str]
    :param end_timestamp:
    :type end_timestamp: datetime
    :param last_successful_timestamp:
    :type last_successful_timestamp: datetime
    :param ci_error:
    :type ci_error: ~dynamics.customerinsights.api.models.CIResult
    :param ci_errors:
    :type ci_errors: list[~dynamics.customerinsights.api.models.CIResult]
    :param additional_info:
    :type additional_info:
     ~dynamics.customerinsights.api.models.CustomTaskInformation
    :param selection_reason:
    :type selection_reason:
     ~dynamics.customerinsights.api.models.SelectionReason
    """

    _attribute_map = {
        'operation_type': {'key': 'operationType', 'type': 'str'},
        'sub_type': {'key': 'subType', 'type': 'str'},
        'identifier': {'key': 'identifier', 'type': 'str'},
        'friendly_name': {'key': 'friendlyName', 'type': 'str'},
        'job_ids': {'key': 'jobIds', 'type': '[str]'},
        'task_status': {'key': 'taskStatus', 'type': 'str'},
        'last_success_job_ids': {'key': 'lastSuccessJobIds', 'type': '[str]'},
        'end_timestamp': {'key': 'endTimestamp', 'type': 'iso-8601'},
        'last_successful_timestamp': {'key': 'lastSuccessfulTimestamp', 'type': 'iso-8601'},
        'ci_error': {'key': 'ciError', 'type': 'CIResult'},
        'ci_errors': {'key': 'ciErrors', 'type': '[CIResult]'},
        'additional_info': {'key': 'additionalInfo', 'type': 'CustomTaskInformation'},
        'selection_reason': {'key': 'selectionReason', 'type': 'SelectionReason'},
    }

    def __init__(self, *, operation_type=None, sub_type=None, identifier: str=None, friendly_name: str=None, job_ids=None, task_status=None, last_success_job_ids=None, end_timestamp=None, last_successful_timestamp=None, ci_error=None, ci_errors=None, additional_info=None, selection_reason=None, **kwargs) -> None:
        super(GraphNodeInfo, self).__init__(**kwargs)
        self.operation_type = operation_type
        self.sub_type = sub_type
        self.identifier = identifier
        self.friendly_name = friendly_name
        self.job_ids = job_ids
        self.task_status = task_status
        self.last_success_job_ids = last_success_job_ids
        self.end_timestamp = end_timestamp
        self.last_successful_timestamp = last_successful_timestamp
        self.ci_error = ci_error
        self.ci_errors = ci_errors
        self.additional_info = additional_info
        self.selection_reason = selection_reason



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ParsingError(Model):
    """ParsingError.

    :param messages:
    :type messages: list[~dynamics.customerinsights.api.models.LogMessage]
    :param code: Possible values include: 'unknown', 'parsingFailed',
     'entityNotFound', 'attributeNotFound', 'unsupportedSyntax',
     'invalidOperation', 'incorrectArgumentCount', 'incorrectIntervalType',
     'invalidArgument'
    :type code: str or ~dynamics.customerinsights.api.models.enum
    """

    _attribute_map = {
        'messages': {'key': 'messages', 'type': '[LogMessage]'},
        'code': {'key': 'code', 'type': 'str'},
    }

    def __init__(self, *, messages=None, code=None, **kwargs) -> None:
        super(ParsingError, self).__init__(**kwargs)
        self.messages = messages
        self.code = code



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataInfo(Model):
    """DataInfo.

    :param kind: Possible values include: 'resource', 'entity', 'custom'
    :type kind: str or ~dynamics.customerinsights.api.models.enum
    :param change_type: Possible values include: 'none', 'new', 'update'
    :type change_type: str or ~dynamics.customerinsights.api.models.enum
    :param name: Gets the name of the data info.
    :type name: str
    """

    _attribute_map = {
        'kind': {'key': 'kind', 'type': 'str'},
        'change_type': {'key': 'changeType', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(DataInfo, self).__init__(**kwargs)
        self.kind = kwargs.get('kind', None)
        self.change_type = kwargs.get('change_type', None)
        self.name = kwargs.get('name', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DatasourceEntityInformation(Model):
    """Represents the entity info used in API requests (entity level).

    :param entity_name: Name of the entity.
    :type entity_name: str
    :param primary_key: Primary key name of the entity. We require the entity
     to have a single column primary key column
    :type primary_key: str
    :param entity_type: Possible values include: 'unspecified', 'profile',
     'conflationMap', 'activity', 'aggregateKpi', 'profileKpi',
     'unifiedActivity', 'segment', 'intelligence', 'genericPrediction',
     'enrichment', 'insights', 'derivedEntity', 'corrupt', 'selfConflation',
     'conflationManualReview', 'selfConflationManualReview',
     'semanticActivity', 'segmentMembership', 'hierarchy', 'dataLineage',
     'transform', 'semanticEntity'
    :type entity_type: str or ~dynamics.customerinsights.api.models.enum
    :param timestamp_field_name: Time stamp field name.
    :type timestamp_field_name: str
    :param semantic_labels: Semantic labels by attribute name.
    :type semantic_labels:
     list[~dynamics.customerinsights.api.models.AttributeSemanticInformation]
    :param entity_enrichment_info:
    :type entity_enrichment_info:
     ~dynamics.customerinsights.api.models.EntityEnrichmentInformation
    :param delta_table_version: Gets theDeltaTable version of this entity.
    :type delta_table_version: long
    :param auto_generate_cdm_definition: Specifies if CDM definition for this
     entity should be auto generated.
    :type auto_generate_cdm_definition: bool
    """

    _attribute_map = {
        'entity_name': {'key': 'entityName', 'type': 'str'},
        'primary_key': {'key': 'primaryKey', 'type': 'str'},
        'entity_type': {'key': 'entityType', 'type': 'str'},
        'timestamp_field_name': {'key': 'timestampFieldName', 'type': 'str'},
        'semantic_labels': {'key': 'semanticLabels', 'type': '[AttributeSemanticInformation]'},
        'entity_enrichment_info': {'key': 'entityEnrichmentInfo', 'type': 'EntityEnrichmentInformation'},
        'delta_table_version': {'key': 'deltaTableVersion', 'type': 'long'},
        'auto_generate_cdm_definition': {'key': 'autoGenerateCDMDefinition', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(DatasourceEntityInformation, self).__init__(**kwargs)
        self.entity_name = kwargs.get('entity_name', None)
        self.primary_key = kwargs.get('primary_key', None)
        self.entity_type = kwargs.get('entity_type', None)
        self.timestamp_field_name = kwargs.get('timestamp_field_name', None)
        self.semantic_labels = kwargs.get('semantic_labels', None)
        self.entity_enrichment_info = kwargs.get('entity_enrichment_info', None)
        self.delta_table_version = kwargs.get('delta_table_version', None)
        self.auto_generate_cdm_definition = kwargs.get('auto_generate_cdm_definition', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ODataInnerError(Model):
    """ODataInnerError.

    :param properties:
    :type properties: dict[str,
     ~dynamics.customerinsights.api.models.ODataValue]
    :param message:
    :type message: str
    :param type_name:
    :type type_name: str
    :param stack_trace:
    :type stack_trace: str
    :param inner_error:
    :type inner_error: ~dynamics.customerinsights.api.models.ODataInnerError
    """

    _attribute_map = {
        'properties': {'key': 'properties', 'type': '{ODataValue}'},
        'message': {'key': 'message', 'type': 'str'},
        'type_name': {'key': 'typeName', 'type': 'str'},
        'stack_trace': {'key': 'stackTrace', 'type': 'str'},
        'inner_error': {'key': 'innerError', 'type': 'ODataInnerError'},
    }

    def __init__(self, *, properties=None, message: str=None, type_name: str=None, stack_trace: str=None, inner_error=None, **kwargs) -> None:
        super(ODataInnerError, self).__init__(**kwargs)
        self.properties = properties
        self.message = message
        self.type_name = type_name
        self.stack_trace = stack_trace
        self.inner_error = inner_error



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GraphJobOptions(Model):
    """GraphJobOptions.

    :param additional_properties: Unmatched properties from the message are
     deserialized this collection
    :type additional_properties: dict[str, object]
    :param run_downstream_after_merge:
    :type run_downstream_after_merge: bool
    """

    _attribute_map = {
        'additional_properties': {'key': '', 'type': '{object}'},
        'run_downstream_after_merge': {'key': 'runDownstreamAfterMerge', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(GraphJobOptions, self).__init__(**kwargs)
        self.additional_properties = kwargs.get('additional_properties', None)
        self.run_downstream_after_merge = kwargs.get('run_downstream_after_merge', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SegmentMembershipCriteria(Model):
    """Represents a base Segment Query.

    :param kind: Possible values include: 'post', 'default', 'consent',
     'engagement'
    :type kind: str or ~dynamics.customerinsights.api.models.enum
    :param logical_operator: Possible values include: 'and', 'or'
    :type logical_operator: str or ~dynamics.customerinsights.api.models.enum
    :param attribute: Gets the Attribute of the entity used in segment
     criteria.
    :type attribute: str
    :param comparison_operator: Possible values include: 'equals',
     'notEquals', 'greaterThan', 'greaterThanOrEqualTo', 'lessThan',
     'lessThanOrEqualTo', 'any', 'contains', 'startsWith', 'endsWith',
     'isNull', 'isNotNull', 'all', 'isIn', 'isWithinLast', 'isBetween',
     'isNotBetween', 'yearToDate', 'dayOf', 'monthOf', 'yearOf', 'dayOfWeek',
     'timeAt', 'childOf', 'parentOf'
    :type comparison_operator: str or
     ~dynamics.customerinsights.api.models.enum
    :param child_criterias: Gets the list of Child criteria of segment.
    :type child_criterias:
     list[~dynamics.customerinsights.api.models.SegmentMembershipCriteria]
    :param value: Gets the Value in criteria.
    :type value: str
    :param ignore_case: Gets a value indicating whether case is ignored for
     this criteria.
    :type ignore_case: bool
    :param list_of_values: Gets the list of values in criteria.
    :type list_of_values: list[str]
    :param is_time: flag set to true if entries are of time format
    :type is_time: bool
    """

    _attribute_map = {
        'kind': {'key': 'kind', 'type': 'str'},
        'logical_operator': {'key': 'logicalOperator', 'type': 'str'},
        'attribute': {'key': 'attribute', 'type': 'str'},
        'comparison_operator': {'key': 'comparisonOperator', 'type': 'str'},
        'child_criterias': {'key': 'childCriterias', 'type': '[SegmentMembershipCriteria]'},
        'value': {'key': 'value', 'type': 'str'},
        'ignore_case': {'key': 'ignoreCase', 'type': 'bool'},
        'list_of_values': {'key': 'listOfValues', 'type': '[str]'},
        'is_time': {'key': 'isTime', 'type': 'bool'},
    }

    def __init__(self, *, kind=None, logical_operator=None, attribute: str=None, comparison_operator=None, child_criterias=None, value: str=None, ignore_case: bool=None, list_of_values=None, is_time: bool=None, **kwargs) -> None:
        super(SegmentMembershipCriteria, self).__init__(**kwargs)
        self.kind = kind
        self.logical_operator = logical_operator
        self.attribute = attribute
        self.comparison_operator = comparison_operator
        self.child_criterias = child_criterias
        self.value = value
        self.ignore_case = ignore_case
        self.list_of_values = list_of_values
        self.is_time = is_time



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ODataInstanceAnnotation(Model):
    """ODataInstanceAnnotation.

    :param name:
    :type name: str
    :param value:
    :type value: ~dynamics.customerinsights.api.models.ODataValue
    :param type_annotation:
    :type type_annotation:
     ~dynamics.customerinsights.api.models.ODataTypeAnnotation
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'value': {'key': 'value', 'type': 'ODataValue'},
        'type_annotation': {'key': 'typeAnnotation', 'type': 'ODataTypeAnnotation'},
    }

    def __init__(self, **kwargs):
        super(ODataInstanceAnnotation, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.value = kwargs.get('value', None)
        self.type_annotation = kwargs.get('type_annotation', None)
